pub struct PrefetchRequest {
pub query: Query,
pub duration: Duration,
}Expand description
Installs a standing Query for setting the set of pinned files. The results of this query
must evaluate to a single hash. This collected set of hashes is pinned on the local node for
the given Duration.
use actyx_sdk::service::PrefetchRequest;
use std::time::Duration;
let now = chrono::Utc::now();
let query = format!(
r#"
FEATURES(zøg aggregate timeRange)
FROM isLocal &
appId(com.actyx) &
'files:created' &
from({})
SELECT _.cid"#,
now.to_rfc3339_opts(chrono::SecondsFormat::Secs, true)
)
.parse()
.unwrap();
let request = PrefetchRequest {
query,
duration: Duration::from_secs(60 * 60 * 12),
};Fields
query: QueryAQL Query. Must evaluate to a single array of hashes.
duration: DurationHow long the files should be pinned (until = now + duration)