EventKey

Struct EventKey 

pub struct EventKey {
    pub lamport: LamportTimestamp,
    pub stream: StreamId,
    pub offset: Offset,
}
The sort key of an event

It is sorted first by Lamport timestamp and then by stream ID; this combination is already unique. The offset is included to keep track of progress in OffsetMap.

Fields

lamport: LamportTimestampstream: StreamIdoffset: Offset