pub struct EventKey {
pub lamport: LamportTimestamp,
pub stream: StreamId,
pub offset: Offset,
}Expand description
The sort key of an event
It is sorted first by Lamport timestamp and then by stream ID; this combination is already
unique. The offset is included to keep track of progress in OffsetMap.
Fields
lamport: LamportTimestampstream: StreamIdoffset: OffsetTrait Implementations
Sourceimpl Abomonation for EventKey
impl Abomonation for EventKey
Sourceimpl AddAssign<&EventKey> for OffsetMap
impl AddAssign<&EventKey> for OffsetMap
Sourcefn add_assign(&mut self, other: &EventKey)
fn add_assign(&mut self, other: &EventKey)
Performs the
+= operation. Read moreimpl Copy for EventKey
Sourceimpl<'de> Deserialize<'de> for EventKey
impl<'de> Deserialize<'de> for EventKey
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for EventKey
Sourceimpl Ord for EventKey
impl Ord for EventKey
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for EventKey
impl PartialOrd for EventKey
impl StructuralPartialEq for EventKey